@@ -1,7 +1,7 @@
 #' @export
 dplyr_row_slice.mdl_df <- function(data, i, ..., preserve = FALSE) {
   res <- dplyr_row_slice(as_tibble(data), i, ..., preserve = preserve)
-  build_mable(res, key = !!key_vars(data), model = !!mable_vars(data))
+  build_mable(res, key = !!key_vars(data), model = mable_vars(data))
 }
 
 #' @export
@@ -15,7 +15,7 @@ dplyr_col_modify.mdl_df <- function(data, cols) {
   # }
   build_mable(res, 
               key = !!key_vars(data), 
-              model = !!union(mable_vars(data), names(which(is_mdl))))
+              model = union(mable_vars(data), names(which(is_mdl))))
 }
 
 #' @export
@@ -24,7 +24,7 @@ dplyr_reconstruct.mdl_df <- function(data, template) {
   mbl_vars <- names(which(vapply(data, inherits, logical(1L), "lst_mdl")))
   kv <- key_vars(template)
   if(all(kv %in% names(res))) {
-    build_mable(data, key = !!kv, model = !!mbl_vars)
+    build_mable(data, key = !!kv, model = mbl_vars)
   } else {
     as_tibble(res)
   }
